%% Table 4 - Gibbs & Kulish (2017)
% This table compares the sacrifice ratios when inflation is above or
% below the old inflation target.

%% Options - Argentina

% Note that this option is commented out in runSet.m
SET.options.country = 'USA';
runSet;

SET.options.draws   = 5000;

SET.options.unanticipated = 1; % Set to 1 for unanticipated and 0 for anticipated. 
SET.options.anticipated   = 1 - SET.options.unanticipated ; 

SET.param.Delta_ppi = 10;

%% Simulations

SET.param.lambda     = 0.33;
out_33_Arg = SR(SET);

SET.param.lambda     = 0.66;
out_66_Arg = SR(SET);

%% Divded into categories
mean_pre_33_A = mean(squeeze(out_33_Arg.simul.Ycom(4,295:299,:))',2) - SET.param.ppibar;
mean_pre_66_A = mean(squeeze(out_66_Arg.simul.Ycom(4,295:299,:))',2) - SET.param.ppibar;
mean_pre_RE_A = mean(squeeze(out_33_Arg.simul.Y(4,295:299,:))',2) - SET.param.ppibar;

band = 1/400;

% Below and Above 33 U
below_33_A_1 = find(mean_pre_33_A< -band);
above_33_A_1 = find(mean_pre_33_A> band);
trend_33_A_1 = find(mean_pre_33_A>-band & mean_pre_33_A<band);

% Below and Above 66 U
below_66_A_1 = find(mean_pre_66_A<- band);
above_66_A_1 = find(mean_pre_66_A> band);
trend_66_A_1 = find(mean_pre_66_A>-band & mean_pre_66_A<band);

% Below and Above RE U
below_RE_A_1 = find(mean_pre_RE_A< -band);
above_RE_A_1 = find(mean_pre_RE_A> band);
trend_RE_A_1 = find(mean_pre_RE_A>-band & mean_pre_RE_A<band);

%% Below Target
disp('USA - Below Target - Lambda = 0.33')
m_re = mean(out_33_Arg.SR.Ycom.draws(below_33_A_1));
m_out = [' Mean:     ', num2str(m_re)];
disp(m_out)
s_re = std(out_33_Arg.SR.Ycom.draws(below_33_A_1));
s_out = [' St. Dev:  ', num2str(s_re)];
disp(s_out)
k_re = skewness(out_33_Arg.SR.Ycom.draws(below_33_A_1));
k_out = [' Skewness: ', num2str(k_re)];
disp(k_out)
kr_re = kurtosis(out_33_Arg.SR.Ycom.draws(below_33_A_1));
kr_out = [' Kurtosis: ', num2str(kr_re)];
disp(kr_out)
n = length(below_33_A_1);
n_out = [' N:        ', num2str(n)];
disp(n_out)

disp(' ')
disp('USA - Below Target - Lambda = 0.66')
m_re = mean(out_66_Arg.SR.Ycom.draws(below_66_A_1));
m_out = [' Mean:     ', num2str(m_re)];
disp(m_out)
s_re = std(out_66_Arg.SR.Ycom.draws(below_66_A_1));
s_out = [' St. Dev:  ', num2str(s_re)];
disp(s_out)
k_re = skewness(out_66_Arg.SR.Ycom.draws(below_66_A_1));
k_out = [' Skewness: ', num2str(k_re)];
disp(k_out)
kr_re = kurtosis(out_66_Arg.SR.Ycom.draws(below_66_A_1));
kr_out = [' Kurtosis: ', num2str(kr_re)];
disp(kr_out)
n = length(below_66_A_1);
n_out = [' N:        ', num2str(n)];
disp(n_out)

disp(' ')
disp('USA - Below Target - Lambda = 1')
m_re = mean(out_33_Arg.SR.RE.draws(below_RE_A_1));
m_out = [' Mean:     ', num2str(m_re)];
disp(m_out)
s_re = std(out_33_Arg.SR.RE.draws(below_RE_A_1));
s_out = [' St. Dev:  ', num2str(s_re)];
disp(s_out)
k_re = skewness(out_33_Arg.SR.RE.draws(below_RE_A_1));
k_out = [' Skewness: ', num2str(k_re)];
disp(k_out)
kr_re = kurtosis(out_33_Arg.SR.RE.draws(below_RE_A_1));
kr_out = [' Kurtosis: ', num2str(kr_re)];
disp(kr_out)
n = length(below_RE_A_1);
n_out = [' N:        ', num2str(n)];
disp(n_out)

%% Above Target
disp(' ')
disp('USA - Above Target - Lambda = 0.33')
m_re = mean(out_33_Arg.SR.Ycom.draws(above_33_A_1));
m_out = [' Mean:     ', num2str(m_re)];
disp(m_out)
s_re = std(out_33_Arg.SR.Ycom.draws(above_33_A_1));
s_out = [' St. Dev:  ', num2str(s_re)];
disp(s_out)
k_re = skewness(out_33_Arg.SR.Ycom.draws(above_33_A_1));
k_out = [' Skewness: ', num2str(k_re)];
disp(k_out)
kr_re = kurtosis(out_33_Arg.SR.Ycom.draws(above_33_A_1));
kr_out = [' Kurtosis: ', num2str(kr_re)];
disp(kr_out)
n = length(above_33_A_1);
n_out = [' N:        ', num2str(n)];
disp(n_out)

disp(' ')
disp('USA - Above Target - Lambda = 0.66')
m_re = mean(out_66_Arg.SR.Ycom.draws(above_66_A_1));
m_out = [' Mean:     ', num2str(m_re)];
disp(m_out)
s_re = std(out_66_Arg.SR.Ycom.draws(above_66_A_1));
s_out = [' St. Dev:  ', num2str(s_re)];
disp(s_out)
k_re = skewness(out_66_Arg.SR.Ycom.draws(above_66_A_1));
k_out = [' Skewness: ', num2str(k_re)];
disp(k_out)
kr_re = kurtosis(out_66_Arg.SR.Ycom.draws(above_66_A_1));
kr_out = [' Kurtosis: ', num2str(kr_re)];
disp(kr_out)
n = length(above_66_A_1);
n_out = [' N:        ', num2str(n)];
disp(n_out)

disp(' ')
disp('USA - Above Target - Lambda = 1')
m_re = mean(out_33_Arg.SR.RE.draws(above_RE_A_1));
m_out = [' Mean:     ', num2str(m_re)];
disp(m_out)
s_re = std(out_33_Arg.SR.RE.draws(above_RE_A_1));
s_out = [' St. Dev:  ', num2str(s_re)];
disp(s_out)
k_re = skewness(out_33_Arg.SR.RE.draws(above_RE_A_1));
k_out = [' Skewness: ', num2str(k_re)];
disp(k_out)
kr_re = kurtosis(out_33_Arg.SR.RE.draws(above_RE_A_1));
kr_out = [' Kurtosis: ', num2str(kr_re)];
disp(kr_out)
n = length(above_RE_A_1);
n_out = [' N:        ', num2str(n)];
disp(n_out)

%% Full 
disp(' ')
disp('USA - Full - Lambda = 0.33')
m_re = mean(out_33_Arg.SR.Ycom.draws);
m_out = [' Mean:     ', num2str(m_re)];
disp(m_out)
s_re = std(out_33_Arg.SR.Ycom.draws);
s_out = [' St. Dev:  ', num2str(s_re)];
disp(s_out)
k_re = skewness(out_33_Arg.SR.Ycom.draws);
k_out = [' Skewness: ', num2str(k_re)];
disp(k_out)
kr_re = kurtosis(out_33_Arg.SR.Ycom.draws);
kr_out = [' Kurtosis: ', num2str(kr_re)];
disp(kr_out)
n = length(out_33_Arg.SR.Ycom.draws);
n_out = [' N:        ', num2str(n)];
disp(n_out)

disp(' ')
disp('USA - Full - Lambda = 0.66')
m_re = mean(out_66_Arg.SR.Ycom.draws);
m_out = [' Mean:     ', num2str(m_re)];
disp(m_out)
s_re = std(out_66_Arg.SR.Ycom.draws);
s_out = [' St. Dev:  ', num2str(s_re)];
disp(s_out)
k_re = skewness(out_66_Arg.SR.Ycom.draws);
k_out = [' Skewness: ', num2str(k_re)];
disp(k_out)
kr_re = kurtosis(out_66_Arg.SR.Ycom.draws);
kr_out = [' Kurtosis: ', num2str(kr_re)];
disp(kr_out)
n = length(out_66_Arg.SR.Ycom.draws);
n_out = [' N:        ', num2str(n)];
disp(n_out)

disp(' ')
disp('USA - Full - Lambda = 1')
m_re = mean(out_33_Arg.SR.RE.draws);
m_out = [' Mean:     ', num2str(m_re)];
disp(m_out)
s_re = std(out_33_Arg.SR.RE.draws);
s_out = [' St. Dev:  ', num2str(s_re)];
disp(s_out)
k_re = skewness(out_33_Arg.SR.RE.draws);
k_out = [' Skewness: ', num2str(k_re)];
disp(k_out)
kr_re = kurtosis(out_33_Arg.SR.RE.draws);
kr_out = [' Kurtosis: ', num2str(kr_re)];
disp(kr_out)
n = length(out_33_Arg.SR.RE.draws);
n_out = [' N:        ', num2str(n)];
disp(n_out)