** This program creates Figue 1, Table 1, and Table 2 for Gibbs and Kulish (2017)
* Christopher Gibbs, UNSW
* Created 8/8/2017

clear

*set appropriate directory
cd "/Users/christophergibbs/Dropbox/Gibbs_Kulish/EER Submission/Final Document and Replication Files/Programs/Data"
glo drive = "/Users/christophergibbs/Dropbox/Gibbs_Kulish/EER Submission/Final Document and Replication Files/Programs/Data"

*First let's grab some measures of credibility. 

import excel "cbg_turnover_2015v02jes.xlsx", sheet("data v2015") firstrow

drop code L

rename country location

replace location = lower(location)

rename timetoreg time_to_reappoint

destring time_to_reappoint, replace

replace time_to_reap =. if time_to_reap==-999

destring regular irregular timeinoff legal, replace

replace timeinoff =. if timeinoff==-999
replace legal = . if legal==-999

rename timeinoff tenure

replace location = "russia" if location=="russian federation"

gen temp = regular[_n-1]+irregular[_n-1]
gen new_appointment = 0
replace new_appointment = 1 if regular==1 | irregular==1 | temp==1
drop temp

gen new_irregular_appointment = 0
replace new_irregular = 1 if irregular[_n-1]==1 

save central_bank_governors, replace

*merge data on to sacrifice ratios

use sacrifice_data, clear

gen year = yofd(dofq(quarter))

merge m:1 location year using central_bank_governors

drop if _merge==2

drop _merge

drop if inflation==.

* Did you change central bank governor during a disinflation?

gen temp = regular + irregular

egen replaced_during =max(temp), by(dis_trend_id)
drop temp
replace replaced_during=0 if dis_trend_id==.

** Reappointment

destring numberofact, replace

gen temp = 0 if numberofact!=.
replace temp = 1 if numberofact <0 & numberofact!=.

egen reappointed = max(temp), by(dis_trend_id)

drop temp
replace reappointed=0 if dis_trend_id==.
replace reappointed=. if quarter<=tq(1970q1)


xtset country_id quarter


keep if change>2 & b_sac!=. & inf_ma<50


***** Figure 1 *******
hist b_sac


** Final Regression table 
* Let's do interactions
gen change_new_a = change_inf*new_a
gen change_new_irr = change_inf*new_irr
gen inf_ma_new_a = inf_ma9*new_a
gen inf_ma_new_irr = inf_ma9*new_irr
gen dis_dur_new_a = dis_dura*new_a
gen dis_dur_new_irr = dis_dura*new_irr


*** Table 1

reg b_sac change_inf , cluster(country_id)
loc ops "  tex(frag) dec(2)  nocons nonotes noni   paren(se) stats(coef se) "
outreg2 change   using "$drive\Tab01_new.tex", replace `ops' 

reg b_sac inf_ma9  , cluster(country_id)
loc ops "  tex(frag) dec(2)  nocons  nonotes noni    paren(se) stats(coef se) "
outreg2   inf_ma using "$drive\Tab01_new.tex", append `ops' 

reg b_sac  dis_dura   , cluster(country_id)
loc ops "  tex(frag) dec(2)  nocons nonotes noni    paren(se) stats(coef se) "
outreg2   dis_dur using "$drive\Tab01_new.tex", append `ops' 

reg b_sac  change_inf inf_ma9 dis_dura    , cluster(country_id)
loc ops "  tex(frag) dec(2)  nocons nonotes noni    paren(se) stats(coef se) "
outreg2   change inf_ma dis_dur new_appointment reappoint new_irr using "$drive\Tab01_new.tex", append `ops' 

*** Table 2
**** IMPORTANT!!: This is a throw away regression that is used just to format the
**** the final regression table produced by outreg2.
reg b_sac change_inf change_new_a inf_ma9 inf_ma_new_a dis_dura dis_dur_new_a new_a ,  cluster(country_id)
loc ops "  tex(frag) dec(2)   nonotes noni   paren(se)  stats(coef se) "
outreg2  change inf_ma dis_dur new_a  using "$drive\Tab02_new.tex", replace `ops' addt("FE", "No")

**** Table 2 actually begins
reg b_sac change_inf change_new_a new_a, cluster(country_id)
*loc ops "  tex(frag) dec(2)   nonotes noni  pdec(2) bracket(pval) paren(se) stats(coef se pval) "
outreg2   change_inf change_new_a new_a using "$drive\Tab02_new.tex", append `ops'  addt("FE", "No")

xtreg b_sac change_inf change_new_a new_a, fe cluster(country_id)
*loc ops "  tex(frag) dec(2)    nonotes noni  pdec(2) bracket(pval) paren(se) stats(coef se pval) "
outreg2   change_inf change_new_a new_a using "$drive\Tab02_new.tex", append `ops'  addt("FE", "Yes")

reg b_sac inf_ma9 inf_ma_new_a new_a  , cluster(country_id)
*loc ops "  tex(frag) dec(2)   nonotes noni  pdec(2) bracket(pval) paren(se) stats(coef se pval) "
outreg2   inf_ma9 inf_ma_new_a new_a using "$drive\Tab02_new.tex", append `ops'  addt("FE", "No")

xtreg b_sac inf_ma9 inf_ma_new_a new_a  , fe cluster(country_id)
*loc ops "  tex(frag) dec(2)   nonotes noni  pdec(2) bracket(pval) paren(se) stats(coef se pval) "
outreg2   inf_ma9 inf_ma_new_a new_a using "$drive\Tab02_new.tex", append `ops'  addt("FE", "Yes")

reg b_sac dis_dura  dis_dur_new_a new_a  , cluster(country_id)
*loc ops "  tex(frag) dec(2)    nonotes noni  pdec(2) bracket(pval) paren(se) stats(coef se pval) "
outreg2   dis_dura  dis_dur_new_a new_a using "$drive\Tab02_new.tex", append `ops'  addt("FE", "No")

xtreg b_sac dis_dura  dis_dur_new_a new_a  , fe cluster(country_id)
*loc ops "  tex(frag) dec(2)    nonotes noni  pdec(2) bracket(pval) paren(se) stats(coef se pval) "
outreg2   dis_dura  dis_dur_new_a new_a using "$drive\Tab02_new.tex", append `ops'  addt("FE", "Yes")

reg b_sac change_inf change_new_a inf_ma9 inf_ma_new_a dis_dura dis_dur_new_a new_a ,  cluster(country_id)
*loc ops "  tex(frag) dec(2)   nonotes noni  pdec(2) bracket(pval) paren(se) stats(coef se pval) "
outreg2  change inf_ma dis_dur new_a  using "$drive\Tab02_new.tex", append `ops' addt("FE", "No")

xtreg b_sac change_inf change_new_a inf_ma9 inf_ma_new_a dis_dura dis_dur_new_a new_a , fe cluster(country_id)
*loc ops "  tex(frag) dec(2)   nonotes noni  pdec(2) bracket(pval) paren(se) stats(coef se pval) "
outreg2  change inf_ma dis_dur new_a  using "$drive\Tab02_new.tex", append `ops' addt("FE", "Yes")

